@@ -23,6 +23,7 @@ impl Meta {
      */
     pub async fn root(&self) -> Result<crate::types::MetaRootResponse> {
         let url = "".to_string();
+
         self.client.get(&url).await
     }
 
@@ -56,7 +57,18 @@ impl Meta {
      * * `s: &str` -- The words to show in Octocat's speech bubble.
      */
     pub async fn get_octocat(&self, s: &str) -> Result<String> {
-        let url = format!("/octocat?s={}", s.to_string(),);
+        let mut query = String::new();
+        let mut query_args: Vec<String> = Default::default();
+        if !s.is_empty() {
+            query_args.push(format!("s={}", s));
+        }
+        for (i, n) in query_args.iter().enumerate() {
+            if i > 0 {
+                query.push('&');
+            }
+            query.push_str(n);
+        }
+        let url = format!("/octocat?{}", query);
 
         self.client.get(&url).await
     }
